==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkVPICReader.java <==
// java wrapper for vtkVPICReader object
//

package vtk;
import vtk.*;

public class vtkVPICReader extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStride_4(int id0,int id1,int id2);
  public void SetStride(int id0,int id1,int id2)
    { SetStride_4(id0,id1,id2); }

  private native void SetStride_5(int id0[]);
  public void SetStride(int id0[])
    { SetStride_5(id0); }

  private native int[]  GetStride_6();
  public int[]  GetStride()
    { return GetStride_6(); }

  private native void SetXExtent_7(int id0,int id1);
  public void SetXExtent(int id0,int id1)
    { SetXExtent_7(id0,id1); }

  private native void SetXExtent_8(int id0[]);
  public void SetXExtent(int id0[])
    { SetXExtent_8(id0); }

  private native void SetYExtent_9(int id0,int id1);
  public void SetYExtent(int id0,int id1)
    { SetYExtent_9(id0,id1); }

  private native void SetYExtent_10(int id0[]);
  public void SetYExtent(int id0[])
    { SetYExtent_10(id0); }

  private native void SetZExtent_11(int id0,int id1);
  public void SetZExtent(int id0,int id1)
    { SetZExtent_11(id0,id1); }

  private native void SetZExtent_12(int id0[]);
  public void SetZExtent(int id0[])
    { SetZExtent_12(id0); }

  private native int[]  GetXLayout_13();
  public int[]  GetXLayout()
    { return GetXLayout_13(); }

  private native int[]  GetYLayout_14();
  public int[]  GetYLayout()
    { return GetYLayout_14(); }

  private native int[]  GetZLayout_15();
  public int[]  GetZLayout()
    { return GetZLayout_15(); }

  private native long GetOutput_16();
  public vtkImageData GetOutput() {
    long temp = GetOutput_16();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_17(int id0);
  public vtkImageData GetOutput(int id0) {
    long temp = GetOutput_17(id0);

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPointArrays_18();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_18(); }

  private native String GetPointArrayName_19(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_19(id0); }

  private native int GetPointArrayStatus_20(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_20(id0); }

  private native void SetPointArrayStatus_21(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_21(id0,id1); }

  private native void DisableAllPointArrays_22();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_22(); }

  private native void EnableAllPointArrays_23();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_23(); }

  public vtkVPICReader() { super(); }

  public vtkVPICReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkVPICReader.java <==
// java wrapper for vtkVPICReader object
//

package vtk;
import vtk.*;

public class vtkVPICReader extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStride_4(int id0,int id1,int id2);
  public void SetStride(int id0,int id1,int id2)
    { SetStride_4(id0,id1,id2); }

  private native void SetStride_5(int id0[]);
  public void SetStride(int id0[])
    { SetStride_5(id0); }

  private native int[]  GetStride_6();
  public int[]  GetStride()
    { return GetStride_6(); }

  private native void SetXExtent_7(int id0,int id1);
  public void SetXExtent(int id0,int id1)
    { SetXExtent_7(id0,id1); }

  private native void SetXExtent_8(int id0[]);
  public void SetXExtent(int id0[])
    { SetXExtent_8(id0); }

  private native void SetYExtent_9(int id0,int id1);
  public void SetYExtent(int id0,int id1)
    { SetYExtent_9(id0,id1); }

  private native void SetYExtent_10(int id0[]);
  public void SetYExtent(int id0[])
    { SetYExtent_10(id0); }

  private native void SetZExtent_11(int id0,int id1);
  public void SetZExtent(int id0,int id1)
    { SetZExtent_11(id0,id1); }

  private native void SetZExtent_12(int id0[]);
  public void SetZExtent(int id0[])
    { SetZExtent_12(id0); }

  private native int[]  GetXLayout_13();
  public int[]  GetXLayout()
    { return GetXLayout_13(); }

  private native int[]  GetYLayout_14();
  public int[]  GetYLayout()
    { return GetYLayout_14(); }

  private native int[]  GetZLayout_15();
  public int[]  GetZLayout()
    { return GetZLayout_15(); }

  private native long GetOutput_16();
  public vtkImageData GetOutput() {
    long temp = GetOutput_16();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_17(int id0);
  public vtkImageData GetOutput(int id0) {
    long temp = GetOutput_17(id0);

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPointArrays_18();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_18(); }

  private native String GetPointArrayName_19(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_19(id0); }

  private native int GetPointArrayStatus_20(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_20(id0); }

  private native void SetPointArrayStatus_21(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_21(id0,id1); }

  private native void DisableAllPointArrays_22();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_22(); }

  private native void EnableAllPointArrays_23();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_23(); }

  public vtkVPICReader() { super(); }

  public vtkVPICReader(long id) { super(id); }
  public native long   VTKInit();

}
